@@ -2,10 +2,10 @@
 tests=(
     "/root/project/build/bin/core-tests --gtest_filter=-*ci_skip*:*nosan*"
     "/root/project/build/bin/common-tests --gtest_filter=-*ci_skip*:*nosan*"
-    "/root/project/build/bin/system-tests --gtest_filter=-*realtime*:*nosan*:*error*"
+    "/root/project/build/bin/system-tests --gtest_filter=-*realtime*:*nosan*:*error*:*ci_skip*"
     "/root/project/build/bin/helics_apps-tests --gtest_filter=-*ci_skip*:*nosan*"
-    "/root/project/build/bin/shared-library-tests-cpp --gtest_filter=-*death*:*nosan*"
-    "/root/project/build/bin/shared-library-tests --gtest_filter=-*bad_input*:*evil*:*after_close*:*death*:*nosan*"
+    "/root/project/build/bin/shared-library-tests-cpp --gtest_filter=-*ci_skip*:*death*:*nosan*"
+    "/root/project/build/bin/shared-library-tests --gtest_filter=-*ci_skip*:*bad_input*:*evil*:*after_close*:*death*:*nosan*"
     "/root/project/build/bin/applicationApiTests --gtest_filter=-*ci_skip*:*nosan*"
     "/root/project/build/bin/filterTranslatorTests --gtest_filter=-*ci_skip*:*nosan*"
     "/root/project/build/bin/messageFederateTests --gtest_filter=-*ci_skip*:*nosan*"
