@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2017-2024,
+Copyright (c) 2017-2025,
 Battelle Memorial Institute; Lawrence Livermore National Security, LLC; Alliance for Sustainable
 Energy, LLC.  See the top-level NOTICE for additional details. All rights reserved.
 SPDX-License-Identifier: BSD-3-Clause
@@ -20,10 +20,10 @@ class CombinationFederate: public ValueFederate, public MessageFederate {
   public:
     /** construct a combination federate
     @param name the name of the federate
-    @param fi the federateInfo object to use for the construction information*/
-    explicit CombinationFederate(const std::string& name, FederateInfo& fi)
+    @param fedInfo the federateInfo object to use for the construction information*/
+    explicit CombinationFederate(const std::string& name, FederateInfo& fedInfo)
     {
-        fed = helicsCreateCombinationFederate(name.c_str(), fi.getInfo(), hThrowOnError());
+        fed = helicsCreateCombinationFederate(name.c_str(), fedInfo.getInfo(), hThrowOnError());
     }
     /** construct a combination Federate from a configuration string either a file or json/toml
      * string*/
